from numpy import load
from os.path import join
from torch import device
from torch.cuda import is_available


def get_device(gpu_index=0):
    d = str( device("cuda:"+str(gpu_index) if is_available() else "cpu"))
    if ('cpu' == d):
        print("CPU MODE")
    return device("cuda:"+str(gpu_index) if is_available() else "cpu")

print(type(str(get_device())))

from os.path import dirname

def get_vol6(nums: int, type = 64):
    '''
    获得一个64个序列长度的电池电压第6阶段放电数据
    '''
    # import sys
    # dir_path = abspath('tool.py')
    # print(sys.path[0])
    # chdir(dir_path[0])
    dir_name = dirname(__file__)
    # real_path = join(dir_name,'vol6_64.py')
    real_path = None
    real_path = join(dir_name, 'vol6_64.py')
    if type == 75:
        real_path = join(dir_name,'vol50000.py')

    # abs_path = abspath('tool.py')
    # print(abs_path)
    data = load(real_path)
    if nums > data.shape[0]:
        print('Warning: max size is ', data.shape[0])
    return data[0:nums]


# x = np.zeros((100, 100))

# print(x.shape)
# print(x[0:1010].shape)

# get_vol6_64(10221)


#############################################
# File Name: setup.py
# Author: LiangjunFeng
# Mail: zhumavip@163.com
# Created Time:  2018-4-16 19:17:34
#############################################

from setuptools import setup, find_packages            #这个包没有的可以pip一下

setup(
    name = "wydtools",      #这里是pip项目发布的名称
    version = "0.8.5",  #版本号，数值大的会优先被pip
    keywords = ("pip", "wydtools"),
    description = "Discharge voltage curves",
    long_description = "Discharge voltage curves",
    license = "MIT Licence",

    author = "WYD",
    author_email = "wangyudong2018@ia.ac.cn",

    packages = find_packages(),
    include_package_data = True,
    platforms = "any",
    install_requires = []          #这个项目需要的第三方库
)